6dd383de66888d8081a22ded91063bc5dc2d7061
hiram
  Thu Jan 26 16:22:17 2012 -0800
change rn4 table name of genes_rat to rgdGene2Raw
diff --git src/hg/hgGene/rgdInfo.c src/hg/hgGene/rgdInfo.c
index 75b2932..aa756c1 100644
--- src/hg/hgGene/rgdInfo.c
+++ src/hg/hgGene/rgdInfo.c
@@ -44,33 +44,34 @@
     {
     protAcc = strdup(row[0]);
     sqlFreeResult(&sr);
     return(protAcc);
     }
 else
     {
     sqlFreeResult(&sr);
     return(NULL);
     }
 }
 
 boolean isRgdGene(struct sqlConnection *conn)
 /* Return true if the gene set is RGD Genes. */
 {
-/* The existence of the table genes_rat storing GENES_RAT data from RGD indicates that we 
-are using RGD Genes as our main gene set for this genome. */
-return(hTableExists(sqlGetDatabase(conn), "genes_rat"));
+/* The existence of the table rgdGene2Raw storing
+ * GENES_RAT data from RGD indicates that we are using RGD Genes as
+ * our main gene set for this genome. */
+return(hTableExists(sqlGetDatabase(conn), "rgdGene2Raw"));
 }
 
 static boolean rgdGeneInfoExists(struct section *section, 
 	struct sqlConnection *conn, char *geneId)
 /* Return TRUE if rgdGene info tables exist. */
 {
 char *rgdGeneId = getRgdGeneId(conn, geneId);
 
 if (rgdGeneId == NULL)
     return FALSE;
 else
     return(TRUE);
 }
 
 void do1Colx(char **row, int iCol, char *colName, char *entryName, char *externalUrl)